@@ -12,12 +12,31 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        has_config.lua
 --
 
--- return module
-return require("project/config").has
+local config  = require("project/config")
+local sandbox = require("sandbox/sandbox")
+
+return function (...)
+    local namespace
+    local instance = sandbox.instance()
+    if instance then
+        namespace = instance:namespace()
+    end
+    local names = table.pack(...)
+    for _, name in ipairs(names) do
+        local value = config.get(name)
+        if value == nil and namespace then
+            value = config.get(namespace .. "::" .. name)
+        end
+        if value then
+            return true
+        end
+    end
+    return false
+end
 
