@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        xmake.lua
@@ -35,13 +35,13 @@ language("c")
             "config.includedirs"
         ,   "config.frameworkdirs"
         ,   "config.frameworks"
+        ,   "target.runtimes"
         ,   "target.symbols"
         ,   "target.warnings"
         ,   "target.fpmodels"
         ,   "target.optimize:check"
         ,   "target.vectorexts:check"
         ,   "target.languages"
-        ,   "target.runtimes"
         ,   "target.pcheader"
         ,   "target.includedirs"
         ,   "target.defines"
@@ -60,7 +60,8 @@ language("c")
         ,   "toolchain.sysincludedirs"
         }
     ,   binary = {
-            "config.linkdirs"
+            "target.runtimes"
+        ,   "config.linkdirs"
         ,   "config.frameworkdirs"
         ,   "target.linkdirs"
         ,   "target.frameworkdirs"
@@ -68,7 +69,6 @@ language("c")
         ,   "target.strip"
         ,   "target.symbols"
         ,   "target.optimize:check"
-        ,   "target.runtimes"
         ,   "toolchain.linkdirs"
         ,   "toolchain.rpathdirs"
         ,   "toolchain.frameworkdirs"
@@ -84,7 +84,8 @@ language("c")
         ,   "toolchain.syslinks"
         }
     ,   shared = {
-            "config.linkdirs"
+            "target.runtimes"
+        ,   "config.linkdirs"
         ,   "config.frameworkdirs"
         ,   "target.linkdirs"
         ,   "target.frameworkdirs"
@@ -92,7 +93,6 @@ language("c")
         ,   "target.strip"
         ,   "target.symbols"
         ,   "target.optimize:check"
-        ,   "target.runtimes"
         ,   "toolchain.linkdirs"
         ,   "toolchain.rpathdirs"
         ,   "toolchain.frameworkdirs"
